-- Create view and public synonym for selected info from all_tables

DROP PUBLIC SYNONYM utl_ortab;
DROP VIEW utl_ortab;

CREATE VIEW utl_ortab as
select	owner,
	table_name
from all_tables;

CREATE PUBLIC SYNONYM utl_ortab FOR utl_ortab;



-- Create view & public synonym for selected info from all_tab_caolumns

DROP PUBLIC SYNONYM utl_orcol;
DROP VIEW utl_orcol;

CREATE VIEW utl_orcol as
select	owner,
	table_name,
	column_name,
	SUBSTR(data_type,1,30) as data_type,
	data_length,
	data_precision,
	data_scale,
	nullable,
	column_id
from all_tab_columns;

CREATE PUBLIC SYNONYM utl_orcol FOR utl_orcol;


-- Create view & public synonym for selected info from all_indexes

DROP PUBLIC SYNONYM utl_orind;
DROP VIEW utl_orind;

CREATE VIEW utl_orind as
select	table_owner,
	table_name,
	index_name,
	SUBSTR(index_type,1,12) as index_type,
	uniqueness
from all_indexes;

CREATE PUBLIC SYNONYM utl_orind FOR utl_orind;


-- Create view & public synonym for selected info from all_ind_columns

DROP PUBLIC SYNONYM utl_orindcol;
DROP VIEW utl_orindcol;

CREATE VIEW utl_orindcol as
select	table_owner,
	table_name,
	index_name,
	column_position,
	SUBSTR(column_name,1,30) as column_name
from all_ind_columns;

CREATE PUBLIC SYNONYM utl_orindcol FOR utl_orindcol;	


-- Create view & public synonym for selected info from all_constraints
--
--  Notes:
--   1) all_constraints does not have a "table_owner" column.  So we're
--      not including it and will link this by table_name only.
--   2) We're initially after enough info to build APPX DLU's.  We'll 
--      use type 'R' constraints for these.
--   3) 'C'heck constraints require the search_condition column, which
--       is a long.  This column is not currently included.
--   4) Other info such as the delete_rule are included but not currently
--      utilized by the importer.
--   5) We could add a where clause here to eliminate some rows (such as Check constraints).

DROP PUBLIC SYNONYM utl_orcon;
DROP VIEW utl_orcon;

CREATE VIEW utl_orcon as
select	table_name,
	constraint_name,
--	constraint_type,
	CONCAT(constraint_type, ' ') as constraint_type,
	r_owner,
	r_constraint_name,
	status,
	delete_rule	
from all_constraints;

CREATE PUBLIC SYNONYM utl_orcon FOR utl_orcon;	


-- Create view & public synonym for selected info from all_cons_columns.

DROP PUBLIC SYNONYM utl_orconcol;
DROP VIEW utl_orconcol;

CREATE VIEW utl_orconcol as
select	table_name,
	constraint_name,
	position,
	SUBSTR(column_name,1,30) as column_name
from all_cons_columns;

CREATE PUBLIC SYNONYM utl_orconcol FOR utl_orconcol;	

