/* -------------------------------------------------------------------------- */
/* This script will create and build the tables which are used as input to 
** the APPX database import app so that it can import table definitions for
** SQL/Server.
**
** Tables created:
**	utl_sqltable	
**	utl_sqlcol
**	utl_sqlind
**
** Each of these is defined by an APPX dd in the UTL app.
*/

/* -------------------------------------------------------------------------- */
/*
** Drop each of these tables to get us started.
*/

drop table utl_sqltable
drop table utl_sqlcol
drop table utl_sqlind

/* -------------------------------------------------------------------------- */
/*
** Create utl_sqltable for storing table names.
** Note that the sysname data type is replaced with varchar(128)
*/

create table utl_sqltable
(
	sqltable_qualifier	varchar(128),
	sqltable_owner	 	varchar(128),
	sqltable_name	 	varchar(128)	primary key,
	sqltable_type		varchar(32),
	sqltable_remarks 	varchar(254)
)

/* Populate it with records using sp_tables stored procedure */

insert into utl_sqltable 
	EXEC sp_tables

/* -------------------------------------------------------------------------- */
/*
** Create utl_sqlcol for storing column names.
** Note changed remarks from 254 to 256 for APPX Alignment purposes
*/

create table utl_sqlcol
(
	sqlcol_qualifier	varchar(128),
	sqlcol_owner		varchar(128),
	sqlcol_table_nam	varchar(128),
	sqlcol_nam		varchar(128),
	sqlcol_data_typ		varchar(128),
	sqlcol_typ_nam		varchar(128),
	sqlcol_precision	int,
	sqlcol_len		int,
	sqlcol_scale		smallint,
	sqlcol_radix		smallint,
	sqlcol_null		smallint,
	sqlcol_remarks		varchar(256),
	sqlcol_default		varchar(254),
	sqlcol_sql_data_typ	smallint,
	sqlcol_datetime_sub	smallint,
	sqlcol_octet_len	int,
	sqlcol_ordinal_pos	int,
	sqlcol_is_nullable	varchar(254),
	sqlcol_ss_data_typ	smallint
)

create unique index utl_sqlcol_0 on utl_sqlcol( sqlcol_table_nam, sqlcol_ordinal_pos )

/* Populate it with records using sp_columns stored procedure */

insert into utl_sqlcol
	EXEC sp_columns @table_name = '%'

/* -------------------------------------------------------------------------- */
/*
** Create utl_sqlind for storing index information.
**
** If created from within APPX, will have to 
**    allow NULLS on SQLIND_SEQ & SQLIND_NAM fields.  Since these are part
**    of the key, APPX by default sets them to not null.  However, the
**    statistics record (which is different than the index records) is also
**    created by this stored procedure.  These records have nulls in these
**    fields.
**
** Changed table name from 128 to 112 to get us under the max key size of 255.
**
*/

create table utl_sqlind
 (
	sqlind_qualifier	varchar(128) null,
	sqlind_owner		varchar(128) null,
	sqlind_table_nam	varchar(112) not null,
	sqlind_non_unique 	smallint null,
	sqlind_ind_qualifier 	varchar(128) null,
	sqlind_nam 		varchar(128) null,
	sqlind_type		smallint null,
	sqlind_seq		smallint null,
	sqlind_col_nam		varchar(128) null,
	sqlind_collation	varchar(2) null,
	sqlind_cardinality	int null,
	sqlind_pages		int null,
	sqlind_filter_cond	varchar(128) null
 )

create unique index utl_sqlind_0 on utl_sqlind( sqlind_table_nam, sqlind_nam, sqlind_seq )

/* Populate it with records using sp_statistics stored procedure.
** Wildcard pattern matching does not work with this stored procedure, so we
** will build a cursor with table names from the utl_sqltable created above 
** above and run the stored procedure for each row in that table.
*/

declare tables_cursor cursor for
	select sqltable_name from utl_sqltable
open tables_cursor
declare @tablename sysname
fetch next from tables_cursor into @tablename
while (@@fetch_status <> -1)
begin
	insert into utl_sqlind
		exec sp_statistics @table_name = @tablename
	fetch next from tables_cursor into @tablename
end
close tables_cursor
deallocate tables_cursor

/* --------------------------------------------------------------------------------- */

