/*****************************************************************************
**  NAME: CALL.C
**  
**  Author            : APPX Software, Inc.
**  Date              : 10/26/92
**  Current Revision  : 1.8.0
**
**  Description       : This module is used by the APPX CALL statement.  Any
**			function listed in the 'appx_calls[]' array below
**			can be called using the CALL statement.  
**
**			This source file can be modified by the user, compiled,
**			and linked to the object library distributed with appx
**			in order to CALL routines externally defined. 
**
**			You can call any C runtime function provided the
**			function is named in the appx_calls[] array and the
**			appropriate library is linked.
**			
*****************************************************************************/

/*****************************************************************************
==  INCLUDED FILES
*****************************************************************************/
#include <stdlib.h>

/*****************************************************************************
==  TYPE and STRUCTURE DEFINITIONS
*****************************************************************************/

#ifdef __cplusplus

typedef struct
{
    char     *func_nam;         /* Function name, null terminated       */
    long   (*func_addr)(...);   /* Function address                     */
} func_blk;

#else

typedef struct
{
    char     *func_nam;         /* Function name, null terminated       */
    long   (*func_addr)();      /* Function address                     */
} func_blk;

#endif
/*****************************************************************************
==  IMPORTED FUNCTION DECLARATIONS
*****************************************************************************/

/*****************************************************************************
==  EXPORTED FUNCTION DECLARATIONS
*****************************************************************************/
static long  get_addr( void *, void ** );

/*****************************************************************************
==  EXPORTED VARIABLES
*****************************************************************************/
/*****************************************************************************
**  APPX_CALLS:	
**
**	This array of structures is used by the APPX CALL statement to map
**	function names to function addresses.
**
**	Any function listed in this array may be called using the CALL 
**	statement.  The last entry in the array should be zero-filled.
**	Each entry in this array contains a structure composed of a 
**	null terminated function name and a pointer to the function to
**	call.
*/

#ifdef __cplusplus

func_blk appx_calls[] =
{
    { "get_addr", (long(*)(...))get_addr },	/* Get address of PASS'ed data  */
    { "atol"    , (long(*)(...))atol     },	/* Convert string to long	*/
    { (char *)0 , (long(*)(...))0        }	/* Last entry, must be NULL	*/
};

#else

func_blk appx_calls[] =
{
    { "get_addr", get_addr },	/* Get address of PASS'ed data		*/
    { "atol"    , atol },	/* Convert string to long		*/
    { (char *)0 , (void*) 0 }	/* Last entry, must be NULL		*/
};

#endif
/*****************************************************************************
==  LOCAL ( HIDDEN ) FUNCTION DEFINITIONS
*****************************************************************************/

/*****************************************************************************
**  NAME:  GET_ADDR()
**
**  PURPOSE: 	This (example) function is used to obtain the address of a 
**		PASS'ed data item.
**
**  INPUT:	src - address of first PASS parameter
**		dst - address of alpha field large enough to hold a
**		      a pointer (usually 4 bytes).
**
**  OUTPUT:	This function returns SUCCESS (1). Also, the address 
**		represented by the first parameter is stored in the
**		'dst' parameter.
*/

static long get_addr( void * src, void ** dst )
{
    *dst = src;

    return( 1 );
}
/*****************************************************************************
**  MODIFICATION HISTORY
**
**  DATE      BY    Description
**  --------  ---   ----------------------------------------------------------
**  12/15/93  JAL   Cleanup of compiler warnings - ECR 2212
**  02/22/94  GBC   Deleted typedef of func_blk.  Included file ii.h, which
**                  has a typedef for func_blk.  flexelint error 15.
**  03/24/94  TJD   #ifdef NOT_NEEDED on declaration to remove flint Info 762
**  06/06/94  WJR   Changed ifdef to if for DORMANT, NOT_NEEDED, and OLD_MACROS.
**  01/30/95  KAD   Restored to separately compilable condition, ECR #2611
**  11/27/97  KAD   Integrated C++ support
**
*****************************************************************************/

static char what_str[] = "@(#)appx $Header: /src/cvs/appx/call.c,v 1.13 1997/11/28 01:50:13 korry Exp $";
